# Airflow Kubernetes Base Operator

## What is this?
This should be a generic operator for other airflow k**o to use as their core dependency. 
Maybe you'll find some use in the python kube api wrapper, otherwise probably the specific package for your needs will be better.

## Note
Not to be used yet.